@@ -5,7 +5,7 @@ package Art::World;
 # use Art::Agent;
 #has Art::Agent::Artist @.artists;
 
-our $VERSION = '0.15_02';
+our $VERSION = '0.15_03';
 
 use Zydeco;
 
@@ -17,16 +17,30 @@ class Playground {};
 
 =head1 NAME
 
-Art::World - An Art World simulator game 🎨
+Art::World - Agents interactions modeling  🎨
 
 =head1 SYNOPSIS
 
   use Art::World;
 
+=head1 OBJECTIVES
+
+
+Art::World is an attempt to model and simulate a system describing the interactions and influences between the various I<agents> of the art world.
+
+If a correct API is reached, we'll try to build a "game of art" frontend.
+
 =head1 DESCRIPTION
 
-Art::World is an attempt to model an art world simulation system. If a
-correct API is reached, we'll try to build a "game of art" frontend.
+=begin html
+
+<p>
+  <img alt="Some illustrations sticked on a wall" src="https://gitlab.com/smonff/art-world/-/raw/master/spec/schema_v2.png"
+    width="600px">
+</p>
+
+=end html
+
 
 =over
 
